Module commands

Module commands 

Structs

DisableOptions
Options for the disable command
EnableCliOptions
CLI options for the enable command.
EnableResult
Result of running enable - used by the binary to determine what storage to create.
LogResult
Result of running the log command.
UninstallOptions
Options for the uninstall command
UpgradeOptions
Options for the upgrade command
WatchOptions
Options for the watch command.

Enums

InstallMethod
How mi6 was installed

Functions

default_port
Get the default OTel port.
disable_framework_silent
Disable mi6 hooks for a single framework silently (no output).
ensure_running
Ensure the OTel server is running, starting it if necessary.
get_status
Get the status of the OTel server.
is_server_running
Check if a server is running on the given port.
run_codex_session_scan_by_id
Run the Codex session scan command for a specific session ID.
run_codex_session_scan_file
Run the Codex session scan command for a file path.
run_disable
Run the disable command.
run_enable
Run the enable command.
run_gc
run_log
Run the log command. This must be fast (<10ms) and never block the calling framework.
run_otel_ingest
Run the OTLP ingest command.
run_scan
Run the transcript scan command.
run_server
Run the OTLP HTTP server.
run_session
Run the session command to display session details.
run_status_command
Run the mi6 status command.
run_uninstall
Run the uninstall command
run_upgrade
Run the upgrade command
run_watch
Watch for new events and print them as they arrive
stop_server
Stop the mi6 OTel server running on the given port.