WatchOptions

Struct WatchOptions 

pub struct WatchOptions {
    pub session: Option<String>,
    pub event_type: Option<String>,
    pub permission_mode: Option<String>,
    pub framework: Option<String>,
    pub poll_ms: u64,
}
Options for the watch command.

Using a struct instead of individual parameters makes the API more maintainable and prevents parameter order mistakes, especially with multiple Option<String> fields.

Fields

session: Option<String>

Filter by session ID

event_type: Option<String>

Filter by event type

permission_mode: Option<String>

Filter by permission mode

framework: Option<String>

Filter by framework (claude, gemini, cursor, etc.)

poll_ms: u64

Poll interval in milliseconds (default: 500)

Implementations

Source

impl WatchOptions

pub fn new() -> Self

Create new options with default values.

pub fn session(self, session: impl Into<Option<String>>) -> Self

Set the session filter.

pub fn event_type(self, event_type: impl Into<Option<String>>) -> Self

Set the event type filter.

pub fn permission_mode(self, permission_mode: impl Into<Option<String>>) -> Self

Set the permission mode filter.

pub fn framework(self, framework: impl Into<Option<String>>) -> Self

Set the framework filter.

pub fn poll_ms(self, poll_ms: u64) -> Self

Set the poll interval in milliseconds.