StderrColors

Struct StderrColors 

pub struct StderrColors {
    pub reset: &'static str,
    pub bold: &'static str,
    pub bold_white: &'static str,
    pub bold_green: &'static str,
    pub green: &'static str,
    pub red: &'static str,
    pub cyan: &'static str,
    pub yellow: &'static str,
}
ANSI color codes for terminal output to stderr.

This struct provides a set of ANSI escape codes that are automatically disabled when stderr is not a terminal or when the NO_COLOR environment variable is set.

Fields

reset: &'static strbold: &'static strbold_white: &'static strbold_green: &'static strgreen: &'static strred: &'static strcyan: &'static stryellow: &'static str

Implementations

Source

impl StderrColors

pub fn new() -> Self

Create a new StderrColors instance.

If stderr is not a terminal or NO_COLOR is set, all color codes will be empty strings.