pub fn find_claude_process() -> Option<ClaudeProcessInfo>Expand description
Walk up the process tree to find the Claude Code process.
Claude Code runs as a node process, so we look for that in our process ancestry.
Returns None if we can’t find a node process in the ancestry.