Structs
- Disable
Options - Options for the disable command
- Enable
CliOptions - CLI options for the enable command.
- Enable
Result - Result of running enable - used by the binary to determine what storage to create.
- LogResult
- Result of running the log command.
- Uninstall
Options - Options for the uninstall command
- Upgrade
Options - Options for the upgrade command
- Watch
Options - Options for the
watchcommand.
Enums
- Install
Method - How mi6 was installed
Functions
- default_
port - Get the default OTel port.
- disable_
framework_ silent - Disable mi6 hooks for a single framework silently (no output).
- ensure_
running - Ensure the OTel server is running, starting it if necessary.
- get_
status - Get the status of the OTel server.
- is_
server_ running - Check if a server is running on the given port.
- run_
codex_ session_ scan_ by_ id - Run the Codex session scan command for a specific session ID.
- run_
codex_ session_ scan_ file - Run the Codex session scan command for a file path.
- run_
disable - Run the disable command.
- run_
enable - Run the enable command.
- run_gc
- run_log
- Run the log command. This must be fast (<10ms) and never block the calling framework.
- run_
otel_ ingest - Run the OTLP ingest command.
- run_
scan - Run the transcript scan command.
- run_
server - Run the OTLP HTTP server.
- run_
session - Run the session command to display session details.
- run_
status_ command - Run the mi6 status command.
- run_
uninstall - Run the uninstall command
- run_
upgrade - Run the upgrade command
- run_
watch - Watch for new events and print them as they arrive
- stop_
server - Stop the mi6 OTel server running on the given port.